#
# spec file for package gzip (Version 1.3.5)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           gzip
%define do_profiling 0
Url:            http://www.gzip.org/
License:        GPL v2 or later
Group:          Productivity/Archiving/Compression
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Version:        1.3.5
Release:        159.10.1
Summary:        GNU Zip Compression Utilities
Source:         %{name}-%{version}.tar.bz2
Patch:          gzip-1.3.5.patch
Patch1:         gzip-1.3.5-tempfile.patch
Patch2:         gzip-1.3.5-codecleanup.patch
Patch3:         zgrep.patch
Patch4:         gzip-1.3.5-zmore.patch
Patch5:         traversal.diff
Patch6:         non-exec-stack.diff
Patch7:         http://rsync.samba.org/ftp/unpacked/rsync/patches/gzip-rsyncable.diff
Patch8:         ungzip.diff
#CVE-2010-0001 integer overflow could lead to array index error in  archives, compressed with
#the (LZW) compression algorithm
Patch9:         gzip-CVE-2010-0001.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Gzip reduces the size of the named files using Lempel-Ziv coding LZ77. 
Whenever possible, each file is replaced by one with the extension .gz,
while keeping the same ownership modes and access and modification
times.



Authors:
--------
    Jean-loup Gailly	<gzip@prep.ai.mit.edu>

%prep
%{suse_update_config -f}
%setup
%patch
%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7 -p1
%patch8
%patch9 -p1

%build
export CFLAGS="$RPM_OPT_FLAGS \
%ifarch %{ix86}
    -mcpu=pentiumpro \
%endif
-fomit-frame-pointer -fno-strength-reduce \
-W -Wall -Wno-unused-parameter -Wstrict-prototypes -Wpointer-arith"
./configure --prefix=%{_prefix} --infodir=%{_infodir} --mandir=%{_mandir}
%if %{do_profiling}
  make CFLAGS="$CFLAGS -fprofile-arcs"
  for i in 1 2 3 4 5 6 7 8 9
  do
	time ./gzip -$i <	texinfo.tex	> texinfo.tex.gz
	./gzip --test		texinfo.tex.gz
	./gzip -d	<	texinfo.tex.gz	> texinfo.test$i
	diff			texinfo.tex	  texinfo.test$i
	time ./gzip -$i <	/bin/bash	> bash.gz
	./gzip --test		bash.gz
	./gzip -d       <	bash.gz		> bash.test$i
	cmp			/bin/bash	  bash.test$i
  done
  make clean
  make CFLAGS="$CFLAGS -fbranch-probabilities"
%else
  make
%endif
for i in 1 2 3 4 5 6 7 8 9
do
	time ./gzip -$i <	texinfo.tex	> texinfo.tex.gz
	./gzip --test		texinfo.tex.gz
	./gzip -d	<	texinfo.tex.gz	> texinfo.test$i
	diff			texinfo.tex	  texinfo.test$i
	time ./gzip -$i <	/bin/bash	> bash.gz
	./gzip --test		bash.gz
	./gzip -d       <	bash.gz		> bash.test$i
	cmp			/bin/bash	  bash.test$i
done
ls -l texinfo.test?
ls -l bash.test?

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install
mkdir -p $RPM_BUILD_ROOT/bin
mv $RPM_BUILD_ROOT/usr/bin/gzip $RPM_BUILD_ROOT/bin/
ln -f  $RPM_BUILD_ROOT/bin/gzip $RPM_BUILD_ROOT/bin/zcat
ln -f  $RPM_BUILD_ROOT/bin/gzip $RPM_BUILD_ROOT/bin/gunzip
ln -sf /bin/gzip $RPM_BUILD_ROOT/usr/bin/gzip
ln -sf /bin/gunzip $RPM_BUILD_ROOT/usr/bin/gunzip
ln -sf /bin/zcat $RPM_BUILD_ROOT/usr/bin/zcat
ln -sf zmore $RPM_BUILD_ROOT/usr/bin/zless
ln -sf zmore.1 $RPM_BUILD_ROOT%{_mandir}/man1/zless.1

%files
%defattr(-, root, root)
/bin/*
/usr/bin/*
%doc %{_infodir}/*.gz
%doc %{_mandir}/man*/*.gz

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%changelog
* Thu Jan 14 2010 mseben@novell.com
- addedgzip-CVE-2010-0001.diff  : fix possible denial of service
  and arbitrary code execution
* Wed Sep 13 2006 schwab@suse.de
- Verify hash tables when unpacking [#202365].
* Mon Mar 13 2006 schwab@suse.de
- Add rsyncable patch [#155442].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 11 2005 pth@suse.de
- Don't obsolete compress.
* Mon Oct 31 2005 dmueller@suse.de
- build with non-executable stack
* Tue Jul 26 2005 schwab@suse.de
- Ignore directory part on saved file name [#79292].
* Tue Apr 19 2005 kukuk@suse.de
- Remove uncompress symlink [#78331]
* Thu Mar 24 2005 werner@suse.de
- Add support for bzip2 and simply pager options to zmore
* Mon May  3 2004 schwab@suse.de
- Fix quoting issues in zgrep [#39329].
* Fri Feb 27 2004 schwab@suse.de
- Add %%defattr.
* Tue Dec  2 2003 pthomas@suse.de
- Remove the patch for tail syntax as it's wrong and unnecessary.
* Thu Sep 18 2003 mmj@suse.de
- Fix tail syntax in gzexe [#31229]
* Thu Aug 28 2003 kukuk@suse.de
- Make sure we have no hardlinks from /bin to /usr/bin [Bug #29522]
* Tue Jun 17 2003 pthomas@suse.de
- Update to 1.3.5
  - gzip now removes any output symlink before writing output file.
  - zgrep etc. scripts now port to POSIX 1003.1-2001 hosts.
  - zforce no longer assumes 14-byte file name length limit.
  - zless is now implemented using less and LESSOPEN, not zmore and PAGER.
  - assembly-language speedups reenabled; were mistakenly disabled in 1.3.
  - Less output is lost when decompressing a truncated file.
  - zgrep now supports --, -H, -h, -L, -l, -C, -d, -m and their long
    equivalents.
* Wed Jun  4 2003 jh@suse.de
- Enable profile feedback
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Tue Apr 15 2003 coolo@suse.de
- use BuildRoot
* Sat Feb  8 2003 kukuk@suse.de
- Readded prereq for install-info, else we cannot install info
  pages
- Add dir entry to info page
* Sat Feb  8 2003 ro@suse.de
- removed prereq for texinfo to avoid prereq-cycle
* Fri Feb  7 2003 ro@suse.de
- added install_info macros
* Wed Jan 29 2003 kukuk@suse.de
- Remove mimencode requires, it is optional
* Tue Dec 17 2002 werner@suse.de
- The `:' line of zgrep will be removed by configure
- zgrep requzires mimencode from metamail
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Thu Mar 14 2002 kukuk@suse.de
- Add uncompress compat link
* Wed Feb  6 2002 coolo@suse.de
- use %%suse_update_config
* Thu Jan 24 2002 okir@suse.de
- fixed tempfile race in zdiff (current code used bash noclobber
  which is inherently racey)
* Wed Jun  6 2001 werner@suse.de
- Make zgrep knowing about bzip2
* Tue Apr  3 2001 uli@suse.de
- fixed for gcc >2.96
* Tue Mar 27 2001 bk@suse.de
- use i686 insn scheduling on i386 and strip binaries(performance)
- make tmpfiles in gzexe secure and improve znew tempdir creation
- remove unnessary expr use and fix gzip output checking in zforce
- add simple tests if gzip/gunzip work
* Mon Nov 27 2000 aj@suse.de
- Update to gzip 1.3.
* Wed Aug 23 2000 werner@suse.de
- Security changes for the znew script
* Mon May  1 2000 kukuk@suse.de
- LSB-FHS requires /bin/gunzip and /bin/zcat to /bin/gzip
* Tue Apr 18 2000 kukuk@suse.de
- Add /bin/zcat (required by FHS 2.1)
* Fri Feb 25 2000 schwab@suse.de
- cleanup spec file, get rid of Makefile.Linux
- define _GNU_SOURCE for basename declaration
- /usr/man -> /usr/share/man
- add gzip.info to file list
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Mar  6 1998 florian@suse.de
- fixed security bug posted on Dez 27 to bugtraq
* Thu Jan  8 1998 bs@suse.de
- fixed "double" /bin/gzip & /usr/bin/gzip
* Thu Apr 24 1997 bs@suse.de
- added symlink /bin/gunzip
* Sun Apr 13 1997 florian@suse.de
- add bug-fixes from gnu.utils.bugs
